clear all
close all

%%

N_x = 1936; %size of the image
N_y = 1216; %size of the image

n = 1.43; %refractive index
wavelength = 643e-9; %wavelength of the light. unit of meter.

ImageFolderAddress = 'C:\Users\xuena\Box\Matlab\ElastoCapillary\Figures\Appendix\demo'; % The folder where the images are

ImageFileName = 'fringes.tif'; % The demo image with fringes, under deformation.
ImageFileName_ref = 'fringes_ref.tif'; % The demo image with fringes, without deformatioin (so it is the reference).

N_start = 203;
N_end = 403;

ImageAddress_ref = fullfile(ImageFolderAddress, ImageFileName_ref); % Gives the full address of the image.
ImageAddress = fullfile(ImageFolderAddress, ImageFileName);

%% We first work on the reference image, i.e., when there is no deformation. This sets the zero topography.
    
I_ref = imread(ImageAddress_ref);
I_ref = im2double(I_ref(:, :));

imff_ref=fft2(I_ref);

xcenter = (size(I_ref, 2) + 1)/2;
ycenter = (size(I_ref, 1) + 1)/2;

%% This set the size of the mask.
% Generally, when testing, we use a loop to find the perfect size of the mask so that the result will not affect by the selection of the mask sizes.
% It is also fine to use a non-rectangular mask.

mask_center_x = 993; % Here is the center of the masks. Usually, it is where the peak of intensity is.
mask_center_y = 609;

mask_width = 25;
mask_height = 400;

mask = zeros(size(I_ref, 1), size(I_ref, 2));
mask(round(mask_center_y - mask_height/2) : round(mask_center_y + mask_height/2), ...
    round(mask_center_x - mask_width/2) : round(mask_center_x + mask_width/2)) = 1; % Here, the mask is set.

mask = imgaussfilt(mask, 2); % Here we do a gaussian filt of the mask, but this is not necessary.

%%

f_ref=ifft2(ifftshift(fftshift(imff_ref).*mask)); % Here we apply the fft on the reference image and apply the mask. Then we do the inverse fft.
phase_ref=imag(log(f_ref)); % Here we get the phase map.

phase_unwrap_ref = unwrap_phase(phase_ref); % Here we unwrap the phase map using the unwrap_phase function.

background_ref = repmat(phase_unwrap_ref(1,:), [N_y,1]); % Here we use the top line of the unwrapped result as the background; thus phase_unwrap2_ref - background_ref means the offset of the fringes when there is no deformation.

%% Now we work on processing the fringes where the substrate is deformed.

I = imread(ImageAddress); % read the image
I = im2double(I(:, :));

figure(1) % This show the original image
fig1 = imagesc(I);
axis equal

imff=fftshift(fft2(I)); % Give the FFT

figure(2)
fig2 = imagesc(log(abs(imff)));
axis equal

f1 = imff.*mask; % Apply the mask on imff

figure(3)
fig3 = imagesc(log(abs(f1)));
axis equal

f2 = ifft2(ifftshift(f1)); % Apply the inverse FFT
phase = imag(log(f2)); % Gets the phase map

figure(4)
fig4 = imagesc(phase);
axis equal

phase_unwrap = unwrap_phase(phase); % Here we unwrap the phase map using the unwrap_phase function.
% We note that unwrap function does not work well near the edges (the left
% and right ends of the image), especially when the structure of the
% fringes are complicated.

figure(5)
fig5 = imagesc(phase_unwrap);
axis equal

background = repmat(phase_unwrap(1,:), [N_y,1]); % Here we use the top line of the unwrapped result as the background; This assume that the top line is not deformed.

h_measurment = -(phase_unwrap - background - (phase_unwrap_ref - background_ref)) /(2 * pi) * wavelength / (2 * n); % Get the measurment on the topography.

figure(6)
fig6 = imagesc(h_measurment);
axis equal